#définition du dossier de travail
setwd("C:/Users/Guillaume/Documents/bio-ingénieur/MA2/TFE/Dossier_TFE_Charles_G/Comparaison_pessiere_hetraie/fichiers_sortie_CAT")

#packages
library(tidyverse)
library(ggpubr)
library(rstatix)
library(dplyr)
library(PairedData)
library(writexl)


#import des données et suppression des colonnes vides
tout <- read.csv("comparaison.csv", header = T, sep = ";", dec = ",",  fileEncoding="latin1")

#création de la colonne type et suppression des types inutiles pour le total
tout$type <- "NA"
for (i in 1:nrow(tout)){
  if (tout$Compart[i] == "Biomasse sou") {
    tout$type[i] <- "BS"
  } else if (tout$Compart[i] == "Biomasse aÚr") {
    tout$type[i] <- "BA"
  } else if (tout$Compart[i] == "MatiÞre orga") {
    tout$type[i] <- "MO"
  } else if (tout$Compart[i] == "En usage") {
    tout$type[i] <- "suppr"
  } else if (tout$Compart[i] == "Au site d'en") {
    tout$type[i] <- "suppr"
  } else if (tout$Compart[i] == "Emissions d'") {
    tout$type[i] <- "EM"
  } else if (tout$Compart[i] == "Substitution") {
    tout$type[i] <- "SU"
  } else if (tout$Compart[i] == "Site d'enfou") {
    tout$type[i] <- "suppr"
  } else if (tout$Compart[i] == "Combustion d") {
    tout$type[i] <- "suppr" 
  } else if (tout$Compart[i] == "Biomasse viv") {
    tout$type[i] <- "BV"
  } else if (tout$Compart[i] == "Tous les pro") {
    tout$type[i] <- "PB"
  } else if (tout$Compart[i] == "Flux net cum") {
    tout$type[i] <- "FN"
  }} 

tout <- subset(tout, type != "suppr" & type != "FN" & type != "EM" & type != "BS" & type !="BA") 


#éliminer les colonnes inutiles#
tout <- tout[,c(3:5)]


#changer le nom des colonnes
names(tout) <- c ("MgC","real","type")

#séparer pour les comparaisons
stocks <- subset(tout,type != "SU")
flux <- subset(tout, type == "SU")

#ajouter les stocks totaux
stockstot = stocks %>% group_by(real) %>%
  summarise(MgC = sum(MgC),
            .groups = 'drop')
stockstot$type <-"st"
stockscomplet <- rbind (stocks,stockstot)

#prise des 95%
stocks95 = arrange(stockscomplet,type,MgC)
stocks95$num <- ave(stocks95$MgC,stocks95$type,FUN = seq_along)
stocks95 <- subset(stocks95, stocks95$num > 12 & stocks95$num < 489)

flux95 = arrange(flux,MgC)
flux95$num <- ave(flux95$MgC,FUN = seq_along)
flux95 <- subset(flux95, flux95$num > 12 & flux95$num < 489)

#présentation des résultats

par(mfrow = c(2,1))
mean_MgCm <- tapply(stockscomplet$MgC, stockscomplet$type, mean)
graphiquem = barplot(mean_MgCm, main = "a)", ylab ="Stock de carbone (différence) [tC/ha]", names.arg = c("Biomasse vivante", "Matière organique morte","Produits bois","Ensemble des réservoirs") , xlab = "Réservoir de carbone", cex.lab=1,cex.names=1,space=1, ylim = c(-250,100))
minm <- tapply(stocks95$MgC, stocks95$type, min)
maxm <- tapply(stocks95$MgC, stocks95$type, max)
arrows(graphiquem,minm,graphiquem,maxm, lwd=2, angle=90,length=0.1,code=3)
abline(h = 0, col = "black")

mean_df <- mean(flux$MgC)
graphique = barplot(mean_df,main = "b)", ylab ="Substitution (différence) [tC/(ha.an)]",space=1,width = 0.165, xlim = c(0,0.5), ylim = c(-6,1))
min <- min(flux95$MgC)
max <- max(flux95$MgC)
arrows(graphique,min,graphique,max, lwd=2, angle=90,length=0.1,code=3)
abline(h = 0, col = "black")

#tableau
stockscompletmoy = stockscomplet %>% group_by(type) %>%
  summarise(MgC = mean(MgC),
            .groups = 'drop')
fluxmoy = flux %>% group_by(type) %>%
  summarise(MgC = mean(MgC),
            .groups = 'drop')
moym <- rbind(stockscompletmoy,fluxmoy)
write_xlsx(moym, "C:/Users/Guillaume/Documents/bio-ingénieur/MA2/TFE/Dossier_TFE_Charles_G/Comparaison_pessiere_hetraie/fichiers_sortie_R/moyenne.xlsx")




##billons

#import des données et suppression des colonnes vides
res <- read.csv("r_billons.csv", header = T, sep = ";", dec = ",",  fileEncoding="latin1")
feu <- read.csv("f_billons.csv", header = T, sep = ";", dec = ",",  fileEncoding="latin1")

res <- subset(res,Species == "Picea abies")
res$gf <- "r"
feu$gf <- "f"
tout <- rbind(res,feu)


mV = tout %>% group_by(gf,LogCategor,Species) %>%
  summarise(V = mean(Volume_m3h),
            .groups = 'drop')

write_xlsx(mV, "C:/Users/Guillaume/Documents/bio-ingénieur/MA2/TFE/Dossier_TFE_Charles_G/Comparaison_pessiere_hetraie/fichiers_sortie_R/billons.xlsx")



## PTPBC
ptbr <- read.csv("r_PTPBC.csv", header = T, sep = ";", dec = ",",  fileEncoding="latin1")
ptbf <- read.csv("f_PTPBC.csv", header = T, sep = ";", dec = ",",  fileEncoding="latin1")


ptbr <- subset(ptbr,Species =="Picea abies")
moyr = ptbr %>% group_by(Type,Class) %>%
  summarise(V = mean(Volume_m3h),
            .groups = 'drop')
moyr$gf <- "r"

ptbf <- subset(ptbf,Species =="All species")
moyf = ptbf %>% group_by(Type,Class) %>%
  summarise(V = mean(Volume_m3h),
            .groups = 'drop')
moyf$gf <- "f"

tout <- rbind(moyr,moyf)

write_xlsx(tout, "C:/Users/Guillaume/Documents/bio-ingénieur/MA2/TFE/Dossier_TFE_Charles_G/Comparaison_pessiere_hetraie/fichiers_sortie_R/produits_bois.xlsx")

